.include "system\header.asm"
.include "constants.asm"
.include "system\disclaimer.asm"

.segment "ZEROPAGE"
.include "zero_page.asm" ; reserved vars are defined here

.segment "CODE"
irq_handler:
  jmp main

;;;;;;;;;;;;;;
; RESET
;;;;;;;;;;;;;;

.include "reset_handler.asm" ; ends on a jump to main

;;;;;;;;;;;;;;
; NMI
;;;;;;;;;;;;;;

.include "nmi_handler.asm" ; vblank code goes here (graphics updates).

;;;;;;;;;;;;;;
; MAIN
;;;;;;;;;;;;;;

main:
  lda framedone       ; has this frame been processed yet
  bne main
  
  jsr FamiToneUpdate
  jsr game_timer
  jsr read_controller

oamcleanup:
  jsr clear_oam
  ldx #0
  lda #$ff
:
  sta $0200,x
  inx
  cpx #0
  bne :-

flickering:
  lda flickerflag
  bne :+
  lda #0
  sta oam_pos
  jmp doneflicker
:
  lda last_oam_pos
  clc
  adc #$18
  sta last_oam_pos
  sta oam_pos
doneflicker:

  jsr state_machine 

  lda #$01
  sta framedone

  jmp main

.include "actors\update_p1.asm"
.include "actors\update_p2.asm"
.include "actors\update_girl.asm"
.include "actors\update_man.asm"

;;;;;;;;;;;;;;
; GAME STATE
;;;;;;;;;;;;;;

.include "sm\state_machine.asm"
.include "sm\state_setup_splash.asm"
.include "sm\state_splash.asm"
.include "sm\state_setup_game.asm"
.include "sm\state_game.asm"

;;;;;;;;;;;;;;
; UTILS
;;;;;;;;;;;;;;

.include "utils\clear_oam.asm"
.include "utils\clear_nams.asm"
.include "utils\load_nam.asm"
.include "utils\graphics_turn_on.asm"
.include "utils\graphics_turn_off.asm"

.include "utils\buffer_metasprites.asm"

.include "utils\clear_pal.asm"
.include "utils\start_fade_in.asm"
.include "utils\fade_pal.asm"   ; this is what is used to properly load the palettes.
.include "utils\start_fade_out.asm"
.include "utils\transfer_pal.asm"

.include "utils\game_timer.asm" 
.include "utils\read_controllers.asm"

.include "famitone2.s"

;;;;;;;;;;;;;;
; RODATA
;;;;;;;;;;;;;;

.segment "RODATA" ; The RODATA segment is a segment that is for read only data

pal_splash:
.incbin "data\pal_splash.dat" , 0, 32
pal_level1:
.incbin "data\pal_level1.dat" , 0, 32

nam_level1:
.incbin "data\nam_level1_blacksky.nam"
nam_level1_part2:
.incbin "data\nam_level1_blacksky_on.nam"

.include "metasprites.asm"

sfx_data:
.include "sound\sfx.s"

music_data:
.segment "SAMPLE"
dmc_data:

;;;;;;;;;;;;;;
; VECTORS
;;;;;;;;;;;;;;

.segment "VECTORS"
.addr nmi_handler, reset_handler, irq_handler

;;;;;;;;;;;;;;
; CHR
;;;;;;;;;;;;;;

.segment "CHR"
.incbin "data\chr_level1.chr"
